@@ -11,6 +11,7 @@
 #' @param ... other parameters.
 #' @param which vector with numerics specifying which graphs should be plotted: (1) "Residuals", (2) "Histogram of residuals", (3) "Normal Q-Q", (4) "ACF of residuals", (5) "PACF of residuals", (6) "Decomposition", (7) "Decomposition - zoom".
 #' @param caption list or character with the graphs titles.
+#' @param ylim the y limits of the plot.
 #' @examples \donttest{
 #' myseries <- ipi_c_eu[, "FR"]
 #' mysa <- x13(myseries, spec = c("RSA5c"))
@@ -35,7 +36,7 @@
 #' @name plot
 #' @rdname plot
 #' @export
-plot.decomposition_X11 = function(x, first_date, last_date, caption = "S-I ratio", ...){
+plot.decomposition_X11 = function(x, first_date, last_date, caption = "S-I ratio", ylim, ...){
   if (!inherits(x, "decomposition_X11"))
     stop("use only with \"decomposition_X11\" object")
 
@@ -52,11 +53,14 @@ plot.decomposition_X11 = function(x, first_date, last_date, caption = "S-I ratio
   op <- par()
   freq <- frequency(d10)
   m <- matrix(c(1:freq), nrow = 1, ncol = freq)
-  layout(m,  widths = c(1,rep.int(0.8, ncol(m)-1)))
-  par(cex=0.7, mai=c(0.1,0.3,0.4,0))
-  y_min <- min(d8,d10)
-  y_max <- max(d8,d10)
-  y_lim <- c(y_min - abs(y_min)*0.2, y_max + abs(y_max)*0.2)
+  layout(m,  widths = c(1, rep.int(0.8, ncol(m) - 1)))
+  par(cex = 0.7, mai = c(0.1, 0.3, 0.4, 0))
+  if (missing(ylim)) {
+    y_min <- min(d8,d10)
+    y_max <- max(d8,d10)
+    ylim <- c(y_min - abs(y_min)*0.2, y_max + abs(y_max)*0.2)
+  }
+
   if (freq==12){
     leg<- c("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec")
   }else if (freq==4){
@@ -71,13 +75,13 @@ plot.decomposition_X11 = function(x, first_date, last_date, caption = "S-I ratio
     mm <- cycle(d10)==i
     xd10 <- d10[mm]
     xd8 <- d8[mm]
-    plot(xd10, type="l", col="blue", lty=1, xaxt="n", yaxt = yaxt, ylim=y_lim)
+    plot(xd10, type="l", col="blue", lty=1, xaxt="n", yaxt = yaxt, ylim=ylim)
     points(xd8, col="red", pch="*", xlab="")
     lines(rep(mean(xd10),length(xd10)), col="black", type="l", lty=1)
     legend(x = "bottom", legend=leg[i],inset = 0, bty="n")
     yaxt = "n"
-    par(cex=0.7, mai=c(0.1,0,0.4,0))
-    ylab=""
+    par(cex = 0.7, mai = c(0.1,0,0.4,0))
+    ylab = ""
   }
   mtext(caption[1], side = 3, col = "blue", outer = TRUE, line = -2)
   par(cex = op$cex, mai = op$mai, mfcol = op$mfcol, mfrow = op$mfrow)
@@ -86,14 +90,14 @@ plot.decomposition_X11 = function(x, first_date, last_date, caption = "S-I ratio
 #' @name plot
 #' @rdname plot
 #' @export
-plot.decomposition_SEATS = function(x, first_date, last_date, caption = "S-I ratio", ...){
+plot.decomposition_SEATS = function(x, first_date, last_date, caption = "S-I ratio", ylim, ...){
   if (!inherits(x, "decomposition_SEATS"))
     stop("use only with \"decomposition_SEATS\" object")
 
-  if(!missing(first_date)){
+  if (!missing(first_date)){
     x$components <- window(x$components, start = first_date)
   }
-  if(!missing(last_date)){
+  if (!missing(last_date)){
     x$components <- window(x$components, end = last_date)
   }
 
@@ -108,9 +112,13 @@ plot.decomposition_SEATS = function(x, first_date, last_date, caption = "S-I rat
   m <- matrix(c(1:freq), nrow = 1, ncol = freq)
   layout(m,  widths = c(1,rep.int(0.8, ncol(m)-1)))
   par(cex=0.7, mai=c(0.1,0.3,0.4,0))
-  y_min <- min(z)
-  y_max <- max(z)
-  y_lim <- c(y_min - abs(y_min)*0.2, y_max + abs(y_max)*0.2)
+
+  if (missing(ylim)) {
+    y_min <- min(z)
+    y_max <- max(z)
+    ylim <- c(y_min - abs(y_min)*0.2, y_max + abs(y_max)*0.2)
+  }
+
   if (freq==12){
     leg<- c("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec")
   }else if (freq==4){
@@ -124,7 +132,7 @@ plot.decomposition_SEATS = function(x, first_date, last_date, caption = "S-I rat
   for (i in 1:freq){
     mm <- cycle(z)==i
     zm <- z[mm]
-    plot(zm, type="l", col="blue", lty=1, xaxt="n", yaxt = yaxt, ylim=y_lim)
+    plot(zm, type="l", col="blue", lty=1, xaxt="n", yaxt = yaxt, ylim=ylim)
     lines(rep(mean(zm),length(zm)), col="black", type="l", lty=1)
     points(zm, col="red", pch="*", xlab="")
     legend(x = "bottom", legend=leg[i],inset = 0, bty="n")
@@ -144,6 +152,7 @@ plot.final <- function(x, first_date, last_date, forecast = TRUE,
                        caption = c("sa-trend" = "Y, Sa, trend",
                                    "cal-seas-irr" = "Cal., sea., irr.")[type_chart],
                        ask =  length(type_chart) > 1 && dev.interactive(),
+                       ylim,
                        ...){
 
   type_chart <- match.arg(type_chart, several.ok = TRUE)
@@ -153,12 +162,15 @@ plot.final <- function(x, first_date, last_date, forecast = TRUE,
   all_caption[type_chart] <- caption
   data_plot <- ts.union(x[[1]], x[[2]])
   colnames(data_plot) <- c(colnames(x[[1]]), colnames(x[[2]]))
-  if(!missing(first_date)){
+  if (!missing(first_date)) {
     data_plot <- window(data_plot, start = first_date)
   }
-  if(!missing(last_date)){
+  if (!missing(last_date)) {
     data_plot <- window(data_plot, end = last_date)
   }
+  if (missing(ylim)) {
+    ylim <- NULL
+  }
   general_colors <- c(y = "#F0B400", t = "#1E6C0B", sa = "#155692",
                       cal = "#F0B400", s = "#1E6C0B", i = "#155692")
 
@@ -171,10 +183,10 @@ plot.final <- function(x, first_date, last_date, forecast = TRUE,
     on.exit(devAskNewPage(current_setting))
   }
 
-  if("sa-trend" %in% type_chart){
+  if ("sa-trend" %in% type_chart) {
     # Graph 1: Sa, trend, and y
     series_graph <- c("y", "t", "sa")
-    if(forecast){
+    if (forecast) {
       last_obs_date <- end(x$series[,"y"])
       window(data_plot[, paste0(series_graph,"_f")],
              start = last_obs_date,
@@ -191,18 +203,19 @@ plot.final <- function(x, first_date, last_date, forecast = TRUE,
     par(mar = c(5, 4, 4, 2) + 0.1)
     ts.plot(data_plot[, series_graph],
             col = col,
-            main = all_caption[1], lty = lty)
+            main = all_caption[1], lty = lty,
+            ylim = ylim)
     legend("bottomleft", legend = c("Series", "Trend","Seasonally adjusted"),
            col = general_colors[c("y", "t", "sa")], lty = 1,
            pch = NA_integer_,
-           inset=c(0,1), xpd=TRUE, bty="n")
+           inset = c(0,1), xpd = TRUE, bty = "n")
     dev.flush()
   }
 
-  if("cal-seas-irr" %in% type_chart){
+  if ("cal-seas-irr" %in% type_chart) {
     # Graph 2: Calendar, seasonal and irregular
     series_graph <- c("s", "i")
-    if(forecast){
+    if (forecast) {
       last_obs_date <- end(x$series[,"y"])
       window(data_plot[, paste0(series_graph,"_f")],
              start = last_obs_date,
@@ -217,7 +230,8 @@ plot.final <- function(x, first_date, last_date, forecast = TRUE,
     col <- general_colors[gsub("_.*$", "", series_graph)]
     ts.plot(data_plot[, series_graph],
             col = col,
-            main = all_caption[2],lty = lty)
+            main = all_caption[2], lty = lty,
+            ylim = ylim)
     legend("bottomleft", legend = c("Calendar effects",
                                     "Seas (component)",
                                     "Irregular"),
